<?php
/**
 * vome functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package vome
 */

if ( ! function_exists( 'vome_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function vome_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on vome, use a find and replace
		 * to change 'vome' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'vome', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'main-menu' => esc_html__( 'Main Menu', 'vome' ),
			'footer-menu' => esc_html__( 'Footer Menu', 'vome' )
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'vome_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Enable custom header
		 */
		add_theme_support('custom-header');
		
		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		/**
		 * Enable suporrt for Post Formats
		 *
		 * see: https://codex.wordpress.org/Post_Formats
		 */
		add_theme_support( 'post-formats', array(
			'image',
			'audio',
			'video',
			'gallery',
			'quote',
		) );

		// Add theme support for selective refresh for widgets.
		//add_theme_support( 'customize-selective-refresh-widgets' );

		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );

		// Add support for editor styles.
		add_theme_support( 'editor-styles' );

		// Add support for responsive embedded content.
		add_theme_support( 'responsive-embeds' );

		remove_theme_support( 'widgets-block-editor' );


		add_image_size( 'vome-gallery-thumb', 720, 800, array('center','center') );
		add_image_size( 'vome-case-studies-carousel', 840, 600, array('center','center') );
		add_image_size( 'vome-case-studies-grid', 740, 780, array('center','center') );
		add_image_size( 'vome-case-studies-gallery', 740, 580, array('center','center') );
		add_image_size( 'vome-case-studies-gallery-thumb', 740, 830, array('center','center') );
		add_image_size( 'vome-member-thumb', 540, 580, array('center','center') );
		add_image_size( 'vome-service-thumb', 726, 554, array('center','center') );
	}
endif;
add_action( 'after_setup_theme', 'vome_setup' );


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function vome_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'vome_content_width', 640 );
}
add_action( 'after_setup_theme', 'vome_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function vome_widgets_init() {
	$footer_style_2_switch = get_theme_mod('footer_style_2_switch',true );
	$footer_style_3_switch = get_theme_mod('footer_style_3_switch',true );
	$footer_style_4_switch = get_theme_mod('footer_style_4_switch',true );

	/**
	* blog sidebar
	*/
	register_sidebar( array(
		'name'          => esc_html__( 'Right Sidebar', 'vome' ),
		'id'            => 'right-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'vome' ),
		'before_widget' => '<div id="%1$s" class="widget mb-50 %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="widget-title-box mb-40">
                                    <span class="animate-border"></span>
                                    <h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	/**
	* Footer Widget Style 1 er 1st Widget 
	*/
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Style One', 'vome' ),
		'id'            => 'footer-widget-1',
		'description'   => esc_html__( '1st Widget of Footer Widget Style 1', 'vome' ),
		'before_widget' => '<div id="%1$s" class="footer-area-top ml-15 mb-30 %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="footer-title"><h4>',
		'after_title'   => '</h4></div>',
	) );

	/**
	* Footer Widget Style 1 er 2nd Widget
	*/
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Style Two', 'vome' ),
		'id'            => 'footer-widget-2',
		'description'   => esc_html__( '2nd Widget of Footer Widget Style 1', 'vome' ),
		'before_widget' => '<div id="%1$s" class="footer-area-top pl-30  ml-15 mb-30 %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="footer-title"><h4>',
		'after_title'   => '</h4></div>',
	) );

	/**
	* Footer Widget Style 1 er 3rd Widget
	*/
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Style Three', 'vome' ),
		'id'            => 'footer-widget-3',
		'description'   => esc_html__( '3rd Widget of Footer Widget Style 1', 'vome' ),
		'before_widget' => '<div id="%1$s" class="footer-area-top  ml-15 mb-30 %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="footer-title"><h4>',
		'after_title'   => '</h4></div>',
	) );

	/**
	* Footer Widget Style 1 er 4th Widget
	*/
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Style Four', 'vome' ),
		'id'            => 'footer-widget-4',
		'description'   => esc_html__( '4th Widget of Footer Widget Style 1', 'vome' ),
		'before_widget' => '<div id="%1$s" class="footer-area-top  ml-15 mb-30 %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="footer-title"><h4>',
		'after_title'   => '</h4></div>',
	) );


	/**
	* Footer Widget Style 2
	*/
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 2 Widget Right', 'vome' ),
		'id'            => 'footer-2-widget',
		'description'   => esc_html__( 'Footer 2 Widget Right Menu', 'vome' ),
		'before_widget' => '<div id="%1$s" class="footer-menu-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3>',
		'after_title'   => '</h3>',
	) );


	/**
	* Footer 3 Widget One
	*/
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 3 Widget One', 'vome' ),
		'id'            => 'footer-3-widget-one',
		'description'   => esc_html__( 'Footer 3 Widget One', 'vome' ),
		'before_widget' => '<div id="%1$s" class="footer-3-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3>',
		'after_title'   => '</h3>',
	) );


	/**
	* Footer 3 Widget Two
	*/
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 3 Widget Two', 'vome' ),
		'id'            => 'footer-3-widget-two',
		'description'   => esc_html__( 'Footer 3 Widget Two', 'vome' ),
		'before_widget' => '<div id="%1$s" class="footer-area-top footer-3-widget ml-15 mb-30 %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="footer-title footer-title3"><h4>',
		'after_title'   => '</h4></div>',
	) );	

	/**
	* Footer 3 Widget Three
	*/
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 3 Widget Three', 'vome' ),
		'id'            => 'footer-3-widget-three',
		'description'   => esc_html__( 'Footer 3 Widget Three', 'vome' ),
		'before_widget' => '<div id="%1$s" class="footer-area-top footer-3-widget ml-15 mb-30 f-right %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="footer-title footer-title3"><h4>',
		'after_title'   => '</h4></div>',
	) );



	/**
	* Footer 4 Widget Three
	*/
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 4 Widget', 'vome' ),
		'id'            => 'footer-4-widget',
		'description'   => esc_html__( 'Footer 4 Widget', 'vome' ),
		'before_widget' => '<div class="col-xl-4 col-lg-4"><div id="%1$s" class="footer-widget mb-30 %2$s">',
		'after_widget'  => '</div></div>',
		'before_title'  => '<h4 class="footer-w-title">',
		'after_title'   => '</h4>',
	) );

	/**
	* Service Widget
	*/
	register_sidebar(
		array(
			'name' 			=> esc_html__( 'Service Sidebar', 'vome' ),
			'id' 			=> 'services-sidebar',
			'description' 	=> esc_html__( 'Widgets in this area will be shown on Service Details Sidebar.', 'vome' ),
			'before_title' 	=> '<div class="widget-title-box mb-30">
                    <h3 class="widget-title">',
			'after_title' 	=> '</h3></div>',
			'before_widget' => '<div class="service-widget mb-50 %2$s">',
			'after_widget' 	=> '</div>',
		)
	);

	/**
	* Portfolio Widget
	*/
	register_sidebar(
		array(
			'name' 			=> esc_html__( 'Portfolio Sidebar', 'vome' ),
			'id' 			=> 'portfolio-sidebar',
			'description' 	=> esc_html__( 'Widgets in this area will be shown on Portfolio Details Sidebar.', 'vome' ),
			'before_title' 	=> '<h3>',
			'after_title' 	=> '</h3>',
			'before_widget' => '<div class="portfolio-sidebar  %2$s">',
			'after_widget' 	=> '</div>',
		)
	);

}
add_action( 'widgets_init', 'vome_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
define('VOME_THEME_DIR', get_template_directory() );
define('VOME_THEME_URI', get_template_directory_uri());
define('VOME_THEME_CSS_DIR', VOME_THEME_URI.'/css/');
define('VOME_THEME_JS_DIR', VOME_THEME_URI.'/js/');
define('VOME_THEME_INC', VOME_THEME_DIR.'/inc/');

/** 
 * vome_scripts description
 * @return [type] [description]
 */
function vome_scripts() {
	/**
	* all css files
	*/
	wp_enqueue_style( 'vome-fonts', vome_fonts_url(), array(), '1.0.0' );
	wp_enqueue_style( 'bootstrap', VOME_THEME_CSS_DIR.'bootstrap.min.css', array() );
	wp_enqueue_style( 'animate', VOME_THEME_CSS_DIR.'animate.min.css', array() );
	wp_enqueue_style( 'magnific-popup', VOME_THEME_CSS_DIR.'magnific-popup.css', array() );
	wp_enqueue_style( 'meanmenu-min', VOME_THEME_CSS_DIR.'meanmenu.min.css', array() );
	wp_enqueue_style( 'owl-carousel', VOME_THEME_CSS_DIR.'owl.carousel.min.css', array() );
	wp_enqueue_style( 'fontawesome-all', VOME_THEME_CSS_DIR.'fontawesome.all.min.css', array() );
	wp_enqueue_style( 'slick', VOME_THEME_CSS_DIR.'slick.css', array() );
	wp_enqueue_style( 'slinky-min', VOME_THEME_CSS_DIR.'slinky.min.css', array() );
	wp_enqueue_style( 'vome-default', VOME_THEME_CSS_DIR.'default.css', array() );
	wp_enqueue_style( 'barfiller', VOME_THEME_CSS_DIR.'barfiller.css', array() );
	wp_enqueue_style( 'vome-main', VOME_THEME_CSS_DIR.'main.css', array() );
	wp_enqueue_style( 'vome-style', get_stylesheet_uri() );
	wp_enqueue_style( 'vome-responsive', VOME_THEME_CSS_DIR.'responsive.css', array() );

	$my_current_lang = apply_filters( 'wpml_current_language', NULL );
	$rtl_enable =get_theme_mod( 'rtl_switch',false);
    if ( $my_current_lang  != 'en' && $rtl_enable ) {
		wp_enqueue_style( 'vome-rtl', VOME_THEME_CSS_DIR . 'rtl.css', array() );
		wp_enqueue_style( 'vome-rtl-responsive', VOME_THEME_CSS_DIR . 'rtl-responsive.css', array() );
	}
	else {
		
	}

	// all js
	wp_enqueue_script( 'popper', VOME_THEME_JS_DIR.'popper.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'bootstrap', VOME_THEME_JS_DIR.'bootstrap.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'slick', VOME_THEME_JS_DIR.'slick.min.js', array('jquery','imagesloaded'), false, true );
	wp_enqueue_script( 'owl-carousel', VOME_THEME_JS_DIR.'owl.carousel.min.js', array('jquery'), false, true );
	wp_enqueue_script( 'isotope-pkgd', VOME_THEME_JS_DIR.'isotope.pkgd.min.js', array('jquery'), false, true );
	wp_enqueue_script( 'jquery-meanmenu', VOME_THEME_JS_DIR.'jquery.meanmenu.min.js', array('jquery'), false, true );
	wp_enqueue_script( 'waypoint', VOME_THEME_JS_DIR.'waypoint.js', array('jquery'), false, true );
	wp_enqueue_script( 'jquery-counterup', VOME_THEME_JS_DIR.'jquery.counterup.min.js', array('jquery'), false, true );
	wp_enqueue_script( 'wow', VOME_THEME_JS_DIR.'wow.min.js', array('jquery'), false, true );
	wp_enqueue_script( 'jquery-scrollup', VOME_THEME_JS_DIR.'jquery.scrollUp.min.js', array('jquery'), false, true );
	wp_enqueue_script( 'slinky-min', VOME_THEME_JS_DIR.'slinky.min.js', array('jquery'), false, true );
	wp_enqueue_script( 'jquery-barfiller', VOME_THEME_JS_DIR.'jquery.barfiller.js', array('jquery'), false, true );
	wp_enqueue_script( 'jquery-magnific-popup', VOME_THEME_JS_DIR.'jquery.magnific-popup.min.js', array('jquery'), false, true );
	wp_enqueue_script( 'tilt-jquery', VOME_THEME_JS_DIR.'tilt.jquery.min.js', array('jquery'), false, true );
	wp_enqueue_script( 'vome-plugins', VOME_THEME_JS_DIR.'plugins.js', array('jquery'), false, true );

	if ( $my_current_lang  != 'en' && $rtl_enable ) {
		wp_enqueue_script( 'vome-rtl-main', VOME_THEME_JS_DIR.'rtl-main.js', array('jquery'), false, true );
	}
	else{
		wp_enqueue_script( 'vome-rtl-main', VOME_THEME_JS_DIR.'main.js', array('jquery'), false, true );
	}

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'vome_scripts' );

/*
Register Fonts
*/

function vome_fonts_url() {
    $font_url = '';
    
    /*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Google font: on or off', 'vome' ) ) {
        $font_url =  'https://fonts.googleapis.com/css2?family=Karla:wght@400;700&family=Playfair+Display:wght@400;500;600;700;900&family=Rufina:wght@400;700&display=swap';
    }
    return $font_url;
}




/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Custom template helper function for this theme.
 */
require get_template_directory() . '/inc/template-helper.php';


/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
* include vome functions file
*/
require_once VOME_THEME_INC . 'vome_navwalker.php';
require_once VOME_THEME_INC . 'vome_customizer.php';
require_once VOME_THEME_INC . 'vome_customizer_data.php';
require_once VOME_THEME_INC . 'class-tgm-plugin-activation.php';
require_once VOME_THEME_INC . 'vome_add_plugin.php';



/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function vome_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'vome_pingback_header' );


/**
*
* comment section
*
*/
add_filter('comment_form_default_fields', 'vome_comment_form_default_fields_func');

function vome_comment_form_default_fields_func($default){
	$default['author'] = '<div class="row">
                            <div class="col-xl-6">
                            	<div class="contacts-name">
                            		<label>'.esc_html__('Your name *','vome').'</label>
                                	<input type="text" name="author">
                                </div>
                            </div>';
	$default['email'] = '<div class="col-xl-6">
							<div class="contacts-email ">
							<label>'.esc_html__('Your email *','vome').'</label>
                            <input type="text" name="email">
                        	</div>
                        </div>';
	$default['url'] = '';

	$default['clients_commnet'] = '<div class="col-xl-12">
									<div class="contacts-message">
									<label>'.esc_html__('Comments *','vome').'</label>
                                     <textarea id="comment" name="comment" cols="30" rows="10"></textarea>
                                    </div>';
	return $default;
}

add_filter('comment_form_defaults', 'vome_comment_form_defaults_func');

function vome_comment_form_defaults_func($info){
	if( !is_user_logged_in() ){
		$info['comment_field'] = '';
		$info['submit_field'] = '%1$s %2$s</div></div>';
	}else {
		$info['comment_field'] = '<div class="comments-textarea contacts-message contact-icon">
											<label>'.esc_html__('Comments *','vome').'</label>
                                                <textarea id="comment" name="comment" cols="30" rows="10"></textarea>';
        $info['submit_field'] = '%1$s %2$s</div>';
	}


	$info['submit_button'] = '<button class="btn orange-bg btn-icon bl-btn" type="submit">'.esc_html__('Post Comment','vome').' </button>';

	$info['title_reply_before'] = '<div class="post-comments-title">
                                        <h2>';
	$info['title_reply_after'] = '</h2></div>';
	$info['comment_notes_before'] = '';

	return $info;
}

if( !function_exists('vome_comment') ) {
	function vome_comment($comment, $args, $depth) {
		$GLOBAL['comment'] = $comment;
		extract($args, EXTR_SKIP);
		$args['reply_text'] = '<i class="fas fa-reply-all"></i> Reply';
		$replayClass = 'comment-depth-' . esc_attr($depth);
		?>
			<li id="comment-<?php comment_ID(); ?>" <?php comment_class($replayClass); ?>>
				<div class="comments-box">
					<div class="comments-avatar">
						<?php print get_avatar($comment, 102, null, null, array('class'=> array())); ?>
					</div>
					<div class="comments-text">
						<div class="avatar-name">
							<h5><?php print get_comment_author_link(); ?></h5>
							<span><?php comment_time( get_option('date_format') ); ?></span>
							<?php comment_reply_link( array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth'] ))); ?>
						</div>
						<?php comment_text(); ?>
					</div>
				</div>
		<?php
	}
}



/**
* shortcode supports for removing extra p, spance etc
*
*/
add_filter( 'the_content', 'vome_shortcode_extra_content_remove' );
/**
 * Filters the content to remove any extra paragraph or break tags
 * caused by shortcodes.
 *
 * @since 1.0.0
 *
 * @param string $content  String of HTML content.
 * @return string $content Amended string of HTML content.
 */
function vome_shortcode_extra_content_remove( $content ) {

    $array = array(
        '<p>['    => '[',
        ']</p>'   => ']',
        ']<br />' => ']'
    );
    return strtr( $content, $array );

}

// vome_search_filter_form
if(!function_exists('vome_search_filter_form')){
  function vome_search_filter_form( $form ) {
    
    $form = sprintf( 
    	'<div class="sidebar-form"><form class="search-form" action="%s" method="get">
      	<input type="text" value="%s" required name="s" placeholder="%s">
      	<button type="submit"> <i class="fas fa-search"></i>  </button>
		</form></div>',
		esc_url( home_url('/')),
		esc_attr( get_search_query()),
		esc_html__('Search','vome')
	);

    return $form;
  }
  add_filter( 'get_search_form','vome_search_filter_form');
}

add_action('admin_enqueue_scripts', 'vome_admin_custom_scripts');
function vome_admin_custom_scripts(){
	wp_enqueue_media();
	wp_register_script('vome-admin-custom', get_template_directory_uri().'/inc/js/admin_custom.js', array('jquery'), '', true);
	wp_enqueue_script('vome-admin-custom');

}


// enable_rtl
function vome_enable_rtl(){
	if(get_theme_mod( 'rtl_switch',false)) {
		return ' dir="rtl" ';
	}
	else{
		return '';
	}
}
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328864&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        