<?php

/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package vome
 */

/**
 *
 * vome header
 */
add_action('vome_header_style', 'vome_check_header', 10);

function vome_check_header()
{
    $vome_header_style = get_post_meta(get_the_ID(), 'vome_choice_header_style', true);
    $vome_default_header_style = get_theme_mod('choose_default_header', 'header-style-1');

    if ($vome_header_style == 'header-style-1') {
        vome_header_style_1();
    } elseif ($vome_header_style == 'header-style-2') {
        vome_header_style_2();
    } elseif ($vome_header_style == 'header-style-3') {
        vome_header_style_3();
    } elseif ($vome_header_style == 'header-style-4') {
        vome_header_style_4();
    } else {

        /** default header style **/
        if ($vome_default_header_style == 'header-style-1') {
            vome_header_style_1();
        } elseif ($vome_default_header_style == 'header-style-2') {
            vome_header_style_2();
        } elseif ($vome_default_header_style == 'header-style-3') {
            vome_header_style_3();
        } elseif ($vome_default_header_style == 'header-style-4') {
            vome_header_style_4();
        }
    }
}


/**
 * header style 1 + default
 */

function vome_header_style_1()
{

    $vome_show_header_button = get_theme_mod('vome_show_header_button');
    $vome_user_url = get_theme_mod('vome_user_url');
    $vome_show_header_search = get_theme_mod('vome_show_header_search');
    $btn_text_from_page = get_post_meta(get_the_ID(), 'button_text_from_page', true);

    $vome_menu_column = ($vome_show_header_button) ? 'col-xl-6 col-lg-7' : 'col-xl-10 col-lg-10';
    $vome_menu_pos = ($vome_show_header_button) ? 'text-center' : 'text-right';

    if ($btn_text_from_page) {
        $btn_text = get_post_meta(get_the_ID(), 'button_text_from_page', true);
        $btn_link = get_post_meta(get_the_ID(), 'button_url_from_page', true);
    } else {

        if (rtl_enable()) {
            $btn_text = get_theme_mod('vome_header_btn_text_rtl', 'Sign up');
        } else {
            $btn_text = get_theme_mod('vome_header_btn_text', 'Sign up');
        }

        $btn_link = get_theme_mod('vome_header_btn_link', '#');
    }
?>
    <!-- header start -->
    <header id="header" class="header-transparrent header-log">
        <div class="header-area header-padding">
            <div class="container-fluid">
                <div class="row align-items-center">
                    <div class="col-xl-2 col-lg-2">
                        <div class="logo-area">
                            <div class="logo">
                                <?php vome_header_logo(); ?>
                            </div>
                        </div>
                    </div>
                    <div class="<?php print esc_attr($vome_menu_column); ?>">
                        <div class="menu-area flex-grow-1 <?php print esc_attr($vome_menu_pos); ?>">
                            <div class="main-menu">
                                <nav id="mobile-menu">
                                    <?php vome_header_menu(); ?>
                                </nav>
                            </div>
                        </div>
                    </div>
                    <?php if ($vome_show_header_button === 1) : ?>
                        <div class="col-xl-4 col-lg-3 d-none d-lg-block">
                            <div class="header-right">
                                <div class="header-button f-right">
                                    <a href="<?php print esc_attr($btn_link); ?>" class="btn orange-bg btn-icon">
                                        <?php print esc_html($btn_text); ?> <i class="fal fa-plus"></i>
                                    </a>
                                </div>
                                <div class="header-search-user f-right d-none d-xl-block">
                                    <ul class="list-inline">
                                        <?php if (!empty($vome_show_header_search)) : ?>
                                            <li><a class="nav-search search-trigger" href="#"><i class="fal fa-search"></i></a></li>
                                        <?php endif; ?>

                                        <?php if (!empty($vome_user_url)) : ?>
                                            <li><a href="<?php print esc_url($vome_user_url); ?>"><i class="fal fa-user"></i></a></li>
                                        <?php endif; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    <?php endif;  ?>
                    <!-- mobile-menu -->
                    <div class="col-12">
                        <div class="mobile-menu"></div>
                    </div>
                </div>
            </div>
        </div>
    </header>
    <!-- header end -->
    <main>
    <?php
}

/**
 * header style 2
 */
function vome_header_style_2()
{
    $vome_show_header_button = get_theme_mod('vome_show_header_button');
    $btn_text_from_page = get_post_meta(get_the_ID(), 'button_text_from_page', true);

    if ($btn_text_from_page) {
        $btn_text = get_post_meta(get_the_ID(), 'button_text_from_page', true);
        $btn_link = get_post_meta(get_the_ID(), 'button_url_from_page', true);
    } else {

        $btn_text = get_theme_mod('vome_header_btn_text', 'free trial');
        $btn_link = get_theme_mod('vome_header_btn_link', '#');
    }

    ?>

        <header id="header" class="header-transparrent header-log">
            <div class="header-area header-padding h2-header-padding">
                <div class="container-fluid">
                    <div class="row align-items-center">
                        <div class="col-xl-2 col-lg-2">
                            <div class="logo-area">
                                <div class="logo">
                                    <?php vome_header_logo(); ?>
                                </div>
                            </div>
                        </div>
                        <div class="col-xl-7 col-lg-7">
                            <div class="menu-area h2-menu-area">
                                <div class="main-menu main-menu2">
                                    <nav id="mobile-menu">
                                        <?php vome_header_menu(); ?>
                                    </nav>
                                </div>
                            </div>
                        </div>
                        <?php if ($vome_show_header_button === 1) : ?>
                            <div class="col-xl-3 col-lg-3">
                                <div class="header-box text-right">
                                    <div class="header-right">
                                        <div class="header-button d-none d-lg-block">
                                            <a href="<?php print esc_attr($btn_link); ?>" class="b-btn mr-3"><?php print esc_html($btn_text); ?> <i class="fal fa-plus"></i></a>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        <?php endif; ?>
                        <!-- mobile-menu -->
                        <div class="col-12">
                            <div class="mobile-menu"></div>
                        </div>
                    </div>
                </div>
            </div>
        </header>

        <main>
        <?php
    }
    /**
     * header style 3
     */
    function vome_header_style_3()
    {
        $vome_show_header_search = get_theme_mod('vome_show_header_search');
        $vome_show_header_button = get_theme_mod('vome_show_header_button');
        $btn_text_from_page = get_post_meta(get_the_ID(), 'button_text_from_page', true);

        if ($btn_text_from_page) {
            $btn_text = get_post_meta(get_the_ID(), 'button_text_from_page', true);
            $btn_link = get_post_meta(get_the_ID(), 'button_url_from_page', true);
        } else {
            $btn_text = get_theme_mod('vome_header_btn_text', 'Sign up');
            $btn_link = get_theme_mod('vome_header_btn_link', '#');
        }
        ?>
            <!-- header start -->
            <header id="header" class="header-transparrent header-log">
                <div class="header-area h3-header-padding">
                    <div class="container-fluid">
                        <div class="row">
                            <div class="col-sm-12">
                                <div class="header-box d-flex align-items-center justify-content-between">
                                    <div class="logo-area d-flex align-items-center">
                                        <!-- click-event -->
                                        <div class="clik-event">
                                            <ul class="m-0">
                                                <li class="info-bars"><a class="click-menu-active" href="#"><i class="fas fa-bars"></i></a></li>
                                            </ul>
                                        </div>
                                        <div class="logo">
                                            <?php vome_header_logo(); ?>
                                        </div>
                                    </div>

                                    <?php if (!empty($vome_show_header_search)) : ?>
                                        <div class="search-bar">
                                            <form method="get" action="<?php print esc_url(home_url('/')); ?>">
                                                <input type="search" name="s" value="<?php print esc_attr(get_search_query()) ?>" placeholder="<?php print esc_attr('Search Your Keyword...', 'vome'); ?>">
                                                <i class="fal fa-search"></i>
                                            </form>
                                        </div>
                                    <?php endif; ?>

                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="transparent-mainmenu text-center">
                    <div class="transparent-menu-close-icon">
                        <button class="close-icon">
                            <i class="fal fa-times"></i>
                        </button>
                    </div>
                    <div id="menu-full" class="text-left">
                        <?php vome_header_3_menu(); ?>
                    </div>
                </div>
            </header>
            <!-- header end -->

            <main>

            <?php
        }

        /**
         * vome header style 4
         */
        function vome_header_style_4()
        {
            $vome_show_header_button = get_theme_mod('vome_show_header_button');
            $btn_text_from_page = get_post_meta(get_the_ID(), 'button_text_from_page', true);

            if ($btn_text_from_page) {
                $btn_text = get_post_meta(get_the_ID(), 'button_text_from_page', true);
                $btn_link = get_post_meta(get_the_ID(), 'button_url_from_page', true);
            } else {

                $btn_text = get_theme_mod('vome_header_btn_text', 'Sign up');
                $btn_link = get_theme_mod('vome_header_btn_link', '#');
            }
            ?>
                <!-- header start -->
                <header id="header" class="header-transparrent h4-area header-log">
                    <div class="header-area">
                        <div class="container">
                            <div class="row align-items-center">
                                <div class="col-xl-2 col-lg-2 col-5">
                                    <div class="logo-area h4logo-bg white-bg">
                                        <div class="logo">
                                            <?php vome_header_logo(); ?>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-xl-7 col-lg-7">
                                    <div class="menu-area h4menu-area white-bg">
                                        <div class="main-menu h4main-menu">
                                            <nav id="mobile-menu">
                                                <?php vome_header_menu(); ?>
                                            </nav>
                                        </div>
                                    </div>
                                </div>

                                <?php if ($vome_show_header_button === 1) : ?>
                                    <div class="col-xl-3 col-lg-3">
                                        <div class="header-box">
                                            <div class="header-right">
                                                <div class="header-button h4header-button white-bg m-0 d-none d-lg-block">
                                                    <a href="<?php print esc_attr($btn_link); ?>" class="btn orange-bg gradient-btn"><span><?php print esc_html($btn_text); ?></span></a>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                <?php endif; ?>
                                <!-- mobile-menu -->
                                <div class="col-12">
                                    <div class="mobile-menu"></div>
                                </div>
                            </div>
                        </div>
                    </div>
                </header>
                <!-- header end -->

                <main>

                    <?php
                }


                /**
                 * [vome_header_lang description]
                 * @return [type] [description]
                 */
                function vome_header_lang_defualt()
                {
                    $vome_header_lang            = get_theme_mod('vome_header_lang');
                    if ($vome_header_lang) : ?>
                        <div class="header-lang pos-rel f-right d-none d-xl-block">
                            <div class="lang-icon">
                                <img src="<?php print get_template_directory_uri(); ?>/img/icon/flag.png" alt="<?php print esc_attr('logo', 'vome'); ?>">
                                <a href="#"><?php print esc_html__('English', 'vome'); ?> <i class="far fa-angle-down"></i></a>
                            </div>
                            <?php do_action('vome_language'); ?>
                        </div>
                    <?php endif; ?>
                <?php
                }


                /**
                 * [vome_language_list description]
                 * @return [type] [description]
                 */
                function _vome_language($mar)
                {
                    return $mar;
                }
                function vome_language_list()
                {

                    $mar = '';
                    $languages = apply_filters('wpml_active_languages', NULL, 'orderby=id&order=desc');
                    if (!empty($languages)) {
                        $mar = '<ul class="header-lang-list">';
                        foreach ($languages as $lan) {
                            $active = $lan['active'] == 1 ? 'active' : '';
                            $mar .= '<li class="' . $active . '"><a href="' . $lan['url'] . '">' . $lan['translated_name'] . '</a></li>';
                        }
                        $mar .= '</ul>';
                    } else {
                        //remove this code when send themeforest reviewer team
                        $mar .= '<ul class="header-lang-list">';
                        $mar .= '<li><a href="#">' . esc_html__('USA', 'vome') . '</a></li>';
                        $mar .= '<li><a href="#">' . esc_html__('UK', 'vome') . '</a></li>';
                        $mar .= '<li><a href="#">' . esc_html__('CA', 'vome') . '</a></li>';
                        $mar .= '<li><a href="#">' . esc_html__('AU', 'vome') . '</a></li>';
                        $mar .= ' </ul>';
                    }
                    print _vome_language($mar);
                }
                add_action('vome_language', 'vome_language_list');

                // favicon logo
                function vome_favicon_logo_func()
                {
                    $vome_favicon = get_template_directory_uri() . '/img/logo/favicon.png';
                    $vome_favicon_url = get_theme_mod('favicon_url', $vome_favicon);
                ?>

                    <link rel="shortcut icon" type="image/x-icon" href="<?php print esc_url($vome_favicon_url); ?>">

                <?php
                }
                add_action('wp_head', 'vome_favicon_logo_func');

                // header logo
                function vome_header_logo()
                {
                ?>
                    <?php
                    $vome_logo_on = get_post_meta(get_the_ID(), 'vome_enable_sec_logo', true);
                    $vome_logo = get_template_directory_uri() . '/img/logo/logo.png';
                    $vome_logo_white = get_template_directory_uri() . '/img/logo/logo-black.png';

                    $vome_retina_logo = get_template_directory_uri() . '/img/logo/logo@2x.png';
                    $vome_retina_logo_white = get_template_directory_uri() . '/img/logo/logo-black@2x.png';

                    $vome_retina_logo  = get_theme_mod('retina_logo', $vome_retina_logo);
                    $vome_retina_logo_white  = get_theme_mod('retina_secondary_logo', $vome_retina_logo_white);

                    $vome_site_logo = get_theme_mod('logo', $vome_logo);
                    $vome_secondary_logo = get_theme_mod('seconday_logo', $vome_logo_white);
                    ?>

                    <?php
                    if (has_custom_logo()) {
                        the_custom_logo();
                    } else {

                        if ($vome_logo_on === 'on') { ?>
                            <a class="standard-logo" href="<?php print esc_url(home_url('/')); ?>">
                                <img src="<?php print esc_url($vome_secondary_logo); ?>" alt="<?php print esc_attr('logo', 'vome'); ?>" />
                            </a>
                            <a class="retina-logo" href="<?php print esc_url(home_url('/')); ?>">
                                <img src="<?php print esc_url($vome_retina_logo_white); ?>" alt="<?php print esc_attr('logo', 'vome'); ?>" />
                            </a>
                        <?php
                        } else { ?>
                            <a class="standard-logo" href="<?php print esc_url(home_url('/')); ?>">
                                <img src="<?php print esc_url($vome_site_logo); ?>" alt="<?php print esc_attr('logo', 'vome'); ?>" />
                            </a>
                            <a class="retina-logo" href="<?php print esc_url(home_url('/')); ?>">
                                <img src="<?php print esc_url($vome_retina_logo); ?>" alt="<?php print esc_attr('logo', 'vome'); ?>" />
                            </a>
                    <?php
                        }
                    }
                    ?>
                <?php
                }


                /**
                 * [vome_header_social_profiles description]
                 * @return [type] [description]
                 */
                function vome_header_social_profiles()
                {
                    $vome_topbar_fb_url             = get_theme_mod('vome_topbar_fb_url', '#');
                    $vome_topbar_twitter_url       = get_theme_mod('vome_topbar_twitter_url', '#');
                    $vome_topbar_instagram_url      = get_theme_mod('vome_topbar_instagram_url', '#');
                    $vome_topbar_youtube_url        = get_theme_mod('vome_topbar_youtube_url', '#');
                ?>

                    <?php if ($vome_topbar_fb_url != '#') : ?>
                        <a href="<?php print esc_url($vome_topbar_fb_url); ?>"><i class="fab fa-facebook-f"></i></a>
                    <?php endif; ?>

                    <?php if ($vome_topbar_twitter_url != '#') : ?>
                        <a href="<?php print esc_url($vome_topbar_twitter_url); ?>"><i class="fab fa-twitter"></i></a>
                    <?php endif; ?>

                    <?php if ($vome_topbar_instagram_url != '#') : ?>
                        <a href="<?php print esc_url($vome_topbar_instagram_url); ?>"><i class="fab fa-instagram"></i></a>
                    <?php endif; ?>

                    <?php if ($vome_topbar_youtube_url != '#') : ?>
                        <a href="<?php print esc_url($vome_topbar_youtube_url); ?>"><i class="fab fa-youtube"></i></a>
                    <?php endif; ?>
                <?php
                }


                function vome_footer_social_profiles()
                {
                    $vome_footer_fb_url             = get_theme_mod('vome_footer_fb_url', '#');
                    $vome_footer_twitter_url       = get_theme_mod('vome_footer_twitter_url', '#');
                    $vome_footer_vine_url      = get_theme_mod('vome_footer_vine_url', '#');
                    $vome_footer_weebly_url        = get_theme_mod('vome_footer_weebly_url', '#');
                    $vome_footer_vuejs_url        = get_theme_mod('vome_footer_vuejs_url', '#');
                ?>
                    <ul class="mb-0">
                        <?php if ($vome_footer_fb_url) : ?>
                            <li><a href="<?php print esc_url($vome_footer_fb_url); ?>"><i class="fab fa-facebook-f"></i></a></li>
                        <?php endif; ?>

                        <?php if ($vome_footer_twitter_url) : ?>
                            <li><a href="<?php print esc_url($vome_footer_twitter_url); ?>"><i class="fab fa-twitter"></i></a></li>
                        <?php endif; ?>

                        <?php if ($vome_footer_vine_url) : ?>
                            <li><a href="<?php print esc_url($vome_footer_vine_url); ?>"><i class="fab fa-instagram"></i></a></li>
                        <?php endif; ?>

                        <?php if ($vome_footer_weebly_url) : ?>
                            <li><a href="<?php print esc_url($vome_footer_weebly_url); ?>"><i class="fab fa-linkedin-in"></i></a></li>
                        <?php endif; ?>

                        <?php if ($vome_footer_vuejs_url) : ?>
                            <li><a href="<?php print esc_url($vome_footer_vuejs_url); ?>"><i class="fab fa-youtube"></i></a></li>
                        <?php endif; ?>
                    </ul>
                <?php
                }


                /**
                 * [vome_header_address description]
                 * @return [type] [description]
                 */
                function vome_header_address()
                {
                    $vome_header_address = get_theme_mod('vome_header_address', '15 Hamston Street, West');
                    $vome_address_icon = get_theme_mod('vome_header_address_icon', 'far fa-map-marker-alt');
                ?>
                    <span><i class="<?php print esc_attr($vome_address_icon); ?>"> </i> <?php print esc_html($vome_header_address); ?></span>
                <?php
                }

                /**
                 * [vome_header_phone description]
                 * @return [type] [description]
                 */
                function vome_header_phone()
                {
                    $vome_phone_icon = get_theme_mod('vome_header_phone_icon', 'far fa-phone');
                    $header_phone_label = get_theme_mod('vome_header_phone_label', 'We are available');
                    $vome_phone_number = get_theme_mod('icon_phone', '812 (345) 6789');
                ?>
                    <span class="header-ph"><i class="<?php print esc_attr($vome_phone_icon); ?>"> </i> <?php print esc_html($vome_phone_number); ?></span>
                <?php
                }


                /**
                 * [vome_header_email_address description]
                 * @return [type] [description]
                 */
                function vome_header_email_address()
                {
                    $header_email_icon = get_theme_mod('vome_header_email_icon', 'far fa-envelope-open');
                    $header_email_address = get_theme_mod('vome_header_email_address', 'support@gmail.com');
                ?>
                    <span class="header-en"><i class="<?php print esc_attr($header_email_icon); ?>"></i> <?php print esc_html($header_email_address); ?></span>
                    <?php
                }


                /**
                 * [vome_header_button description]
                 * @return [type] [description]
                 */
                function vome_header_button()
                {
                    $header_show_button      = get_theme_mod('vome_show_header_button');
                    $header_btn_text     = get_theme_mod('vome_header_btn_text', 'Consultancy');
                    $header_btn_icon     = get_theme_mod('vome_header_btn_icon', 'far fa-long-arrow-right');
                    $header_btn_link     = get_theme_mod('vome_header_btn_link', '#');

                    if ($header_show_button && !empty($header_btn_text)) : ?>
                        <a class="btn" href="<?php print esc_url($header_btn_link); ?>"><span class="btn-text"><?php print esc_html($header_btn_text); ?> <i class="<?php print esc_attr($header_btn_icon); ?>"></i></span> </a>
                    <?php endif; ?>

                <?php
                }


                /**
                 * [vome_header_menu description]
                 * @return [type] [description]
                 */
                function vome_header_menu()
                { ?>
                    <?php
                    wp_nav_menu(array(
                        'theme_location'    => 'main-menu',
                        'menu_class'        => '',
                        'container'         => '',
                        'fallback_cb'       => 'vome_Navwalker::fallback',
                        'walker'            => new vome_Navwalker
                    ));
                    ?>
                <?php
                }

                function vome_header_3_menu()
                { ?>
                    <?php
                    wp_nav_menu(array(
                        'theme_location'    => 'main-menu',
                        'menu_class'        => '',
                        'container'         => '',
                    ));
                    ?>
                <?php
                }


                /**
                 * [vome_footer_menu description]
                 * @return [type] [description]
                 */
                function vome_footer_menu()
                {

                    wp_nav_menu(array(
                        'theme_location'    => 'footer-menu',
                        'menu_class'        => 'm-0',
                        'container'         => '',
                        'fallback_cb'       => 'vome_Navwalker::fallback',
                        'walker'            => new vome_Navwalker
                    ));
                }


                /**
                 *
                 * vome footer
                 */
                add_action('vome_footer_style', 'vome_check_footer', 10);

                function vome_check_footer()
                {
                    $vome_footer_style = get_post_meta(get_the_ID(), 'vome_choice_footer_style', true);
                    $vome_default_footer_style = get_theme_mod('choose_default_footer', 'footer-style-1');


                    if ($vome_footer_style == 'footer-style-1') {
                        vome_footer_style_1();
                    } elseif ($vome_footer_style == 'footer-style-2') {
                        vome_footer_style_2();
                    } elseif ($vome_footer_style == 'footer-style-3') {
                        vome_footer_style_3();
                    } elseif ($vome_footer_style == 'footer-style-4') {
                        vome_footer_style_4();
                    } else {

                        /** default footer style **/
                        if ($vome_default_footer_style == 'footer-style-1') {
                            vome_footer_style_1();
                        } elseif ($vome_default_footer_style == 'footer-style-2') {
                            vome_footer_style_2();
                        } elseif ($vome_default_footer_style == 'footer-style-3') {
                            vome_footer_style_3();
                        } elseif ($vome_default_footer_style == 'footer-style-4') {
                            vome_footer_style_4();
                        }
                    }
                }

                /**
                 * footer  style 1 + default
                 */
                function vome_footer_style_1()
                {

                    $vome_footer_bg_url_from_page = get_post_meta(get_the_ID(), 'vome_footer_bg', true);
                    $vome_footer_bg_color_from_page = get_post_meta(get_the_ID(), 'vome_footer_bg_color', true);
                    $vome_footer_social_switch = get_theme_mod('vome_footer_social_switch');
                    $vome_footer_copyright_center = ($vome_footer_social_switch) ? 'col-xl-6 col-lg-8' : 'col-xl-12 col-lg-12 text-center';

                    $vome_copyright_center =  has_nav_menu('footer-menu') ? 'col-lg-6 col-md-7' : 'col-xl-12 col-lg-12 col-md-12 text-center';

                    if ($vome_footer_bg_url_from_page) {
                        $bg_img = get_post_meta(get_the_ID(), 'vome_footer_bg', true);
                    } else {
                        $bg_img = get_theme_mod('vome_footer_bg');
                    }

                    if ($vome_footer_bg_color_from_page) {
                        $bg_color = get_post_meta(get_the_ID(), 'vome_footer_bg_color', true);
                    } else {
                        $bg_color = get_theme_mod('vome_footer_bg_color');
                    }

                ?>

                </main>

                <footer>
                    <!-- footer_stat -->
                    <div class="footer-wrap black-bg" data-background="<?php print esc_url($bg_img); ?>">
                        <?php if (is_active_sidebar('footer-widget-1') || is_active_sidebar('footer-widget-2') || is_active_sidebar('footer-widget-3') || is_active_sidebar('footer-widget-4')) : ?>
                            <div class="footer-top-main pt-100 pb-65">
                                <div class="container">
                                    <div class="row">
                                        <div class="col-xl-3 col-lg-3 col-md-4 col-sm-6">
                                            <?php dynamic_sidebar('footer-widget-1'); ?>
                                        </div>
                                        <div class="col-xl-3 col-lg-3 col-md-4 col-sm-6">
                                            <?php dynamic_sidebar('footer-widget-2'); ?>
                                        </div>
                                        <div class="col-xl-3 col-lg-3 col-md-4 col-sm-6">
                                            <?php dynamic_sidebar('footer-widget-3'); ?>
                                        </div>
                                        <!-- instagram -->
                                        <div class="col-xl-3 col-lg-3 col-md-6">
                                            <?php dynamic_sidebar('footer-widget-4'); ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        <?php endif; ?>
                        <div class="footer-bottom-main">
                            <div class="container">
                                <div class="footer-area-bottom fix">
                                    <div class="row">
                                        <div class="<?php print esc_attr($vome_footer_copyright_center); ?>">
                                            <div class="copy-right">
                                                <p><?php print vome_copyright_text(); ?></p>
                                            </div>
                                        </div>
                                        <?php if (!empty($vome_footer_social_switch)) : ?>
                                            <div class="col-lg-6 col-md-5">
                                                <div class="footer-social text-left text-md-right">
                                                    <?php print vome_footer_social_profiles(); ?>
                                                </div>
                                            </div>
                                        <?php endif; ?>
                                    </div>

                                </div>
                            </div>
                        </div>
                        <!-- </div> -->
                    </div>
                    <!-- footer_end -->
                </footer>

            <?php
                }

                /**
                 * footer  style 2
                 */
                function vome_footer_style_2()
                {

                    $vome_footer_bg_url_from_page = get_post_meta(get_the_ID(), 'vome_footer_bg', true);
                    $vome_footer_bg_color_from_page = get_post_meta(get_the_ID(), 'vome_footer_bg_color', true);
                    $vome_footer_2_bg_left = get_theme_mod('vome_footer_2_bg_left');
                    $vome_footer_2_bg_right = get_theme_mod('vome_footer_2_bg_right');
                    $vome_footer_2_logo = get_theme_mod('vome_footer_2_logo');

                    if ($vome_footer_bg_url_from_page) {
                        $bg_img = get_post_meta(get_the_ID(), 'vome_footer_bg', true);
                    } else {
                        $bg_img = get_theme_mod('vome_footer_bg');
                    }

                    if ($vome_footer_bg_color_from_page) {
                        $bg_color = get_post_meta(get_the_ID(), 'vome_footer_bg_color', true);
                    } else {
                        $bg_color = get_theme_mod('vome_footer_bg_color');
                    }
            ?>

            </main>

            <footer>
                <!-- footer_start -->
                <div class="h2-footer-area black-bg position-relative fix">
                    <!-- footer-bg -->
                    <div class="footer-left-img">
                        <img src="<?php print esc_url($vome_footer_2_bg_left); ?>" alt="<?php print esc_attr__('Logo', 'vome'); ?>">
                    </div>
                    <div class="footer-right-img">
                        <img src="<?php print esc_url($vome_footer_2_bg_right); ?>" alt="<?php print esc_attr__('Logo', 'vome'); ?>">
                    </div>
                    <!-- footer-content -->
                    <div class="h2-footer-content pt-120 pb-100">
                        <div class="container-fluid">
                            <div class="row">
                                <div class="col-xl-6 ">
                                    <div class="h2-footer-contnet-left">
                                        <div class="footer-icon"><img src="<?php print esc_url($vome_footer_2_logo); ?>" alt="<?php print esc_attr__('Logo', 'vome'); ?>"></div>
                                        <div class="footer-copyright">
                                            <p><?php print vome_copyright_text(); ?></p>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-xl-6">
                                    <div class="h2-footer-contnet-right">
                                        <?php dynamic_sidebar('footer-2-widget'); ?>
                                        <div class="h2-footer-social">
                                            <?php print vome_footer_social_profiles(); ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <!-- footer_end -->
            </footer>

        <?php
                }

                /**
                 * footer style 3
                 */
                function vome_footer_style_3()
                {
                    $vome_footer_bg_url_from_page = get_post_meta(get_the_ID(), 'vome_footer_bg', true);
                    $vome_footer_bg_color_from_page = get_post_meta(get_the_ID(), 'vome_footer_bg_color', true);
                    $vome_footer_3_logo = get_theme_mod('vome_footer_3_logo');

                    if ($vome_footer_bg_url_from_page) {
                        $bg_img = get_post_meta(get_the_ID(), 'vome_footer_bg', true);
                    } else {
                        $bg_img = get_theme_mod('vome_footer_bg');
                    }

                    if ($vome_footer_bg_color_from_page) {
                        $bg_color = get_post_meta(get_the_ID(), 'vome_footer_bg_color', true);
                    } else {
                        $bg_color = get_theme_mod('vome_footer_bg_color');
                    }
        ?>

        </main>

        <footer>
            <!-- footer_start -->
            <div class="footer-wrap">
                <div class="footer-top-main pt-100 pb-30">
                    <div class="container">
                        <!-- footer-logo & socal -->
                        <div class="row">
                            <div class="col-xl-2 col-lg-2 col-md-3">
                                <div class="h3-footer-logo mb-30 f-left">
                                    <img src="<?php print esc_url($vome_footer_3_logo); ?>" alt="<?php print esc_attr__('Logo', 'vome'); ?>">
                                </div>
                            </div>
                            <!-- social -->
                            <div class="col-xl-10 col-lg-10 col-md-9">
                                <div class="h3-footer-social f-right mb-80">
                                    <?php print vome_footer_social_profiles(); ?>
                                </div>
                            </div>
                        </div>
                        <!-- footer-content -->
                        <div class="row">
                            <div class="col-xl-7 col-lg-6">
                                <div class="h3-footer-tittle mb-30">
                                    <?php dynamic_sidebar('footer-3-widget-one'); ?>
                                </div>
                            </div>
                            <div class="col-xl-5 col-lg-6">
                                <div class="row">
                                    <div class="col-xl-5 col-lg-6 col-md-4">
                                        <?php dynamic_sidebar('footer-3-widget-two'); ?>
                                    </div>
                                    <div class="col-xl-7 col-lg-6 col-md-4">
                                        <?php dynamic_sidebar('footer-3-widget-three'); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <!-- footer-bottom -->
                <div class="footer-bottom-main">
                    <div class="container">
                        <div class="footer-area-bottom footer-area-bottom2 fix">
                            <div class="row">
                                <div class="col-lg-6 col-md-6">
                                    <div class="copy-right copy-right2 f-left">
                                        <p><?php print vome_copyright_text(); ?></p>
                                    </div>
                                </div>
                                <div class="col-lg-6 col-md-6">
                                    <div class="footer-social footer-terms f-right">
                                        <?php print vome_footer_menu(); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <!-- </div> -->
            </div>
            <!-- footer_end -->
        </footer>

    <?php
                }

                /**
                 * footer style 4
                 */
                function vome_footer_style_4()
                {
                    $vome_footer_bg_url_from_page = get_post_meta(get_the_ID(), 'vome_footer_bg', true);
                    $vome_footer_bg_color_from_page = get_post_meta(get_the_ID(), 'vome_footer_bg_color', true);
                    $vome_footer_4_logo = get_theme_mod('vome_footer_4_logo');

                    if ($vome_footer_bg_url_from_page) {
                        $bg_img = get_post_meta(get_the_ID(), 'vome_footer_bg', true);
                    } else {
                        $bg_img = get_theme_mod('vome_footer_bg');
                    }

                    if ($vome_footer_bg_color_from_page) {
                        $bg_color = get_post_meta(get_the_ID(), 'vome_footer_bg_color', true);
                    } else {
                        $bg_color = get_theme_mod('vome_footer_bg_color');
                    }
    ?>


    </main>

    <footer class="black-bg">
        <!-- footer_stat -->
        <div class="footer-4-wrapper pt-120">
            <div class="container">
                <div class="f-4-border">
                    <div class="f-4-logo-border">
                        <div class="row">
                            <div class="col-xl-5 col-lg-2 col-md-3">
                                <div class="h4-footer-logo mb-30">
                                    <img src="<?php print esc_url($vome_footer_4_logo); ?>" alt="Footer Logo">
                                </div>
                            </div>
                            <!-- social -->
                            <div class="col-xl-7 col-lg-10 col-md-9">
                                <div class="h4-footer-social text-left text-md-right mb-30">
                                    <?php print vome_footer_social_profiles(); ?>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="widget-box">
                        <div class="row">
                            <?php dynamic_sidebar('footer-4-widget'); ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="footer-wrap">
            <div class="footer-bottom-main pt-30 pb-30">
                <div class="container">
                    <div class="row">
                        <div class="col-12">
                            <div class="copy-right text-center">
                                <p><?php print vome_copyright_text(); ?></p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <!-- </div> -->
        </div>
        <!-- footer_end -->
    </footer>
    <?php
                }


                function vome_copyright_text()
                {
                    if (rtl_enable()) {
                        print get_theme_mod('vome_copyright_rtl', esc_html__('Copyright ©2023 Theme_Pure. All Rights Reserved', 'vome'));
                    } else {
                        print get_theme_mod('vome_copyright', esc_html__('Copyright ©2023 Theme_Pure. All Rights Reserved', 'vome'));
                    }
                }

                function vome_design_info()
                {
                    print get_theme_mod('vome_company_info', ('Copyright ©2023 Theme_Pure. All Rights Reserved'));
                }

                /**
                 * [vome_breadcrumb_func description]
                 * @return [type] [description]
                 */
                function vome_breadcrumb_func()
                {
                    $vome_invisible_breadcrumb = get_post_meta(get_the_ID(), 'vome_invisible_breadcrumb', true);
                    if (!$vome_invisible_breadcrumb) {


                        $breadcrumb_bg_img_from_page = get_post_meta(get_the_ID(), 'breadcrumb_bg_img_from_page', true);
                        $bg_img = get_theme_mod('breadcrumb_bg_img');

                        $bg_img = !empty($breadcrumb_bg_img_from_page) ? $breadcrumb_bg_img_from_page : $bg_img;
                        $breadcrumb_blog_title = get_theme_mod('breadcrumb_blog_title', 'Blog ');
                        $breadcrumb_blog_title_details = get_theme_mod('breadcrumb_blog_title_details', 'Blog');

                        $vome_blog_breadcrumb = get_theme_mod('vome_blog_breadcrumb', '');
                        if (is_front_page() && is_home()) { ?>
            <div class="hero-area hero-bg2 position-relative front-home">
                <div class="breadcrumb-bg front-page-space" data-background="<?php print esc_attr($bg_img); ?>">
                    <div class="container">
                        <div class="row">
                            <div class="col-xl-12">
                                <div class="hero-hedding text-center page-titel-padding">
                                    <h1><?php print esc_html($breadcrumb_blog_title); ?> </h1>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php
                        } elseif (is_front_page()) { ?>
            <div class="breadcrumb-area breadcrumb-bg only-front-page">
            </div>
        <?php
                        } elseif (is_home()) { ?>

            <div class="hero-area hero-bg2 position-relative breadcrumb-spacings" data-background="<?php print esc_attr($bg_img); ?>">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-12">
                            <div class="hero-hedding text-center page-titel-padding">
                                <?php
                                if (is_single() && 'post' == get_post_type()) {
                                    if ($vome_blog_breadcrumb == '') { ?>
                                        <h1><?php print esc_html($breadcrumb_blog_title_details); ?></h1>
                                    <?php
                                    } else { ?>
                                        <h1> <?php print esc_html($vome_blog_breadcrumb); ?></h1>
                                    <?php
                                    } ?>

                                <?php
                                } else { ?>
                                    <h1><?php wp_title(''); ?></h1>
                                <?php
                                } ?>
                                <div class="bread-come">
                                    <nav>
                                        <ol class="breadcrumb-menu breadcrumb purple lighten-4 justify-content-center">
                                            <?php vome_breadcrumbs(); ?>
                                        </ol>
                                    </nav>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php
                        } else { ?>
            <div class="hero-area hero-bg2 position-relative breadcrumb-spacings" data-background="<?php print esc_attr($bg_img); ?>">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-12">
                            <div class="hero-hedding text-center page-titel-padding">
                                <?php
                                if (is_single() && 'post' == get_post_type()) {
                                    if ($vome_blog_breadcrumb == '') { ?>
                                        <h1><?php print esc_html($breadcrumb_blog_title_details); ?></h1>
                                    <?php
                                    } else { ?>
                                        <h1> <?php print esc_html($vome_blog_breadcrumb); ?></h1>
                                    <?php
                                    } ?>

                                <?php
                                } else { ?>
                                    <h1><?php wp_title(''); ?></h1>
                                <?php
                                } ?>
                                <nav>
                                    <ol class="breadcrumb-menu">
                                        <?php vome_breadcrumbs(); ?>
                                    </ol>
                                </nav>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
    <?php
                        }
                    }
                }
                add_action('vome_before_main_content', 'vome_breadcrumb_func');


                // gru_search_form
                function vome_search_form()
                { ?>
    <!-- Modal Search -->
    <div class="search-wrap">
        <div class="search-inner">
            <i class="fas fa-times search-close" id="search-close"></i>
            <div class="search-cell">
                <form method="get" action="<?php print esc_url(home_url('/')); ?>">
                    <div class="search-field-holder">
                        <input type="search" name="s" class="main-search-input" value="<?php print esc_attr(get_search_query()) ?>" placeholder="<?php print esc_attr('Search Your Keyword...', 'vome'); ?>">
                    </div>
                </form>
            </div>
        </div>
    </div>

    <?php
                }

                add_action('vome_before_main_content', 'vome_search_form');



                if (!function_exists('vome_breadcrumbs')) {

                    function _vome_home_callback($home)
                    {
                        return $home;
                    }

                    function _vome_breadcrumbs_callback($breadcrumbs)
                    {
                        return $breadcrumbs;
                    }

                    function vome_breadcrumbs()
                    {
                        global $post;

                        $breadcrumb_archive = get_theme_mod('breadcrumb_archive', 'Archive for category ');
                        $breadcrumb_search = get_theme_mod('breadcrumb_search', 'Search results for ');
                        $breadcrumb_post_tags = get_theme_mod('breadcrumb_post_tags', 'Posts tagged ');
                        $breadcrumb_artitle_post_by = get_theme_mod('breadcrumb_artitle_post_by', 'Articles posted by ');
                        $breadcrumb_404 = get_theme_mod('breadcrumb_404', 'Page Not Found ');
                        $breadcrumb_page = get_theme_mod('breadcrumb_page', 'Page ');
                        $breadcrumb_shop = get_theme_mod('breadcrumb_shop', 'Shop ');
                        $breadcrumb_home = get_theme_mod('breadcrumb_home', 'Home ');

                        $home = '<li class="breadcrumb-items"><a href="' . esc_url(home_url('/')) . '" title="' . esc_attr($breadcrumb_home) . '">' . esc_html($breadcrumb_home) . '</a></li>';
                        $showCurrent = 1;
                        $homeLink = esc_url(home_url('/'));
                        if (is_front_page()) {
                            return;
                        }  // don't display breadcrumbs on the homepage (yet)

                        print _vome_home_callback($home);

                        if (is_category()) {
                            // category section
                            $thisCat = get_category(get_query_var('cat'), false);
                            if (!empty($thisCat->parent)) print get_category_parents($thisCat->parent, TRUE, ' ' . '/' . ' ');
                            print '<li class="active">' .  esc_html($breadcrumb_archive) . ' "' . single_cat_title('', false) . '"' . '</li>';
                        } elseif (is_search()) {
                            // search section
                            print '<li class="active">' .  esc_html($breadcrumb_search) . ' "' . get_search_query() . '"' . '</li>';
                        } elseif (is_day()) {
                            print '<li class="breadcrumb-items"><a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a></li>';
                            print '<li class="breadcrumb-items"><a href="' . get_month_link(get_the_time('Y'), get_the_time('m')) . '">' . get_the_time('F') . '</a> </li>';
                            print '<li class="active">' . get_the_time('d') . '</li>';
                        } elseif (is_month()) {
                            // monthly archive
                            print '<li class="breadcrumb-items"><a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> </li>';
                            print '<li class=" active">' . get_the_time('F') . '</li>';
                        } elseif (is_year()) {
                            // yearly archive
                            print '<li class="active">' . get_the_time('Y') . '</li>';
                        } elseif (is_single() && !is_attachment()) {
                            // single post or page
                            if (get_post_type() != 'post') {
                                $post_type = get_post_type_object(get_post_type());
                                $slug = $post_type->rewrite;
                                print '<li class="breadcrumb-items"><a href="' . $homeLink . '/?post_type=' . $slug['slug'] . '">' . $post_type->labels->singular_name . '</a></li>';
                                if ($showCurrent) print '<li class="active">' . get_the_title() . '</li>';
                            } else {
                                $cat = get_the_category();
                                if (isset($cat[0])) {
                                    $cat = $cat[0];
                                } else {
                                    $cat = false;
                                }
                                if ($cat) {
                                    $cats = get_category_parents($cat, TRUE, ' ' . ' ' . ' ');
                                } else {
                                    $cats = false;
                                }
                                if (!$showCurrent && $cats) $cats = preg_replace("#^(.+)\s\s$#", "$1", $cats);
                                print '<li class="breadcrumb-items">' . $cats . '</li>';
                                if ($showCurrent) print '<li class="active">' . get_the_title() . '</li>';
                            }
                        } elseif (!is_single() && !is_page() && get_post_type() != 'post' && !is_404()) {
                            // some other single item
                            $post_type = get_post_type_object(get_post_type());
                            print '<li class="breadcrumb-items">' . $post_type->labels->singular_name . '<li>';
                            if (function_exists('is_shop') and is_shop() && !get_query_var('paged')) {
                                print '<span class="active">' . esc_html($breadcrumb_shop) . '</span>';
                            }
                        } elseif (is_attachment()) {
                            // attachment section
                            $parent = get_post($post->post_parent);
                            $cat = get_the_category($parent->ID);
                            if (isset($cat[0])) {
                                $cat = $cat[0];
                            } else {
                                $cat = false;
                            }
                            if ($cat) print get_category_parents($cat, TRUE, ' ' . ' ' . ' ');
                            print '<li class="breadcrumb-items"><a href="' . get_permalink($parent) . '">' . $parent->post_title . '</a></li>';
                            if ($showCurrent) print  '<li class="active">' . get_the_title() . '</li>';
                        } elseif (is_page() && !$post->post_parent) {

                            // parent page
                            if ($showCurrent)
                                print '<li class="breadcrumb-items"><a href="' . get_permalink() . '">' . get_the_title() . '</a></li>';
                        } elseif (is_page() && $post->post_parent) {
                            // child page
                            $parent_id  = $post->post_parent;
                            $breadcrumbs = array();

                            while ($parent_id) {
                                $page = get_page($parent_id);
                                $breadcrumbs[] = '<li class="breadcrumb-items"><a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a></li>';
                                $parent_id  = $page->post_parent;
                            }
                            $breadcrumbs = array_reverse($breadcrumbs);
                            for ($i = 0; $i < count($breadcrumbs); $i++) {
                                print _vome_breadcrumbs_callback($breadcrumbs[$i]);
                                if ($i != count($breadcrumbs) - 1);
                            }
                            if ($showCurrent) print '<li class="active">' . get_the_title() . '</li>';
                        } elseif (is_tag()) {
                            // tags archive
                            print '<li class="breadcrumb-items">' .  esc_html($breadcrumb_post_tags) . ' "' . single_tag_title('', false) . '"' . '</li>';
                        } elseif (is_author()) {
                            // author archive
                            global $author;
                            $userdata = get_userdata($author);
                            print '<li class="breadcrumb-items">' .  esc_html($breadcrumb_artitle_post_by) . ' ' . $userdata->display_name . '</li>';
                        } elseif (is_404()) {
                            // 404
                            print '<li class="active salim">' . esc_html($breadcrumb_404) . '</li>';
                        }

                        if (get_query_var('paged')) {

                            if (function_exists('is_shop') and is_shop()) {
                                print '<span class="active">' . esc_html($breadcrumb_page) . ' ' . get_query_var('paged') . '</span>';
                            } else {
                                if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author()) print '<li class="breadcrumb-items"> (';
                                print  '<li class="active">' . esc_html($breadcrumb_page) . ' ' . get_query_var('paged') . '</li>';
                                if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author()) print ')</li>';
                            }
                        }
                    }
                }

                /**
                 *
                 * pagination
                 */
                if (!function_exists('vome_pagination')) {

                    function _vome_pagi_callback($home)
                    {
                        return $home;
                    }

                    //page navegation
                    function vome_pagination($prev, $next, $pages, $args)
                    {
                        global $wp_query, $wp_rewrite;
                        $menu = '';
                        $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;

                        if ($pages == '') {
                            global $wp_query;
                            $pages = $wp_query->max_num_pages;

                            if (!$pages)
                                $pages = 1;
                        }

                        $pagination = array(
                            'base' => add_query_arg('paged', '%#%'),
                            'format' => '',
                            'total' => $pages,
                            'current' => $current,
                            'prev_text' => $prev,
                            'next_text' => $next,
                            'type' => 'array'
                        );

                        //rewrite permalinks
                        if ($wp_rewrite->using_permalinks())
                            $pagination['base'] = user_trailingslashit(trailingslashit(remove_query_arg('s', get_pagenum_link(1))) . 'page/%#%/', 'paged');

                        if (!empty($wp_query->query_vars['s']))
                            $pagination['add_args'] = array('s' => get_query_var('s'));

                        $pagi = '';
                        if (paginate_links($pagination) != '') {
                            $paginations = paginate_links($pagination);
                            $pagi .= '<ul>';
                            foreach ($paginations as $key => $pg) {
                                $pagi .= '<li>' . $pg . '</li>';
                            }
                            $pagi .= '</ul>';
                        }

                        print _vome_home_callback($pagi);
                    }
                }


                add_action('admin_print_scripts', 'vome_scripts_for_admin_panel', 1000);

                function vome_scripts_for_admin_panel()
                {
                    if (get_post_type() == 'post') :
    ?>
        <script>
            (function($) {
                "use strict";
                jQuery(document).ready(function() {

                    var tanveer = jQuery("input[name='post_format']:checked").attr('id');

                    if (tanveer == 'post-format-video') {
                        jQuery('.cmb2-id--video-url').show();
                    } else {
                        jQuery('.cmb2-id--video-url').hide();
                    }

                    if (tanveer == 'post-format-audio') {
                        jQuery('.cmb2-id--audio-url').show();
                    } else {
                        jQuery('.cmb2-id--audio-url').hide();
                    }

                    if (tanveer == 'post-format-gallery') {
                        jQuery('.cmb2-id--gallery-images').show();
                    } else {
                        jQuery('.cmb2-id--gallery-images').hide();
                    }

                    jQuery('input[name="post_format"]').change(function() {

                        var tanveer = jQuery("input[name='post_format']:checked").attr('id');

                        if (tanveer == 'post-format-video') {
                            jQuery('.cmb2-id--video-url').show();
                        } else {
                            jQuery('.cmb2-id--video-url').hide();
                        }

                        if (tanveer == 'post-format-audio') {
                            jQuery('.cmb2-id--audio-url').show();
                        } else {
                            jQuery('.cmb2-id--audio-url').hide();
                        }

                        if (tanveer == 'post-format-gallery') {
                            jQuery('.cmb2-id--gallery-images').show();
                        } else {
                            jQuery('.cmb2-id--gallery-images').hide();
                        }
                    });
                })

            })(jQuery);
        </script>

<?php endif;
                }

                // rtl_enable
                function rtl_enable()
                {
                    $my_current_lang = apply_filters('wpml_current_language', NULL);
                    $rtl_enable = get_theme_mod('rtl_switch', false);
                    if ($my_current_lang  != 'en' && $rtl_enable) {
                        return true;
                    } else {
                        return false;
                    }
                }

                // header top bg color
                function vome_breadcrumb_bg_color()
                {
                    $color_code = get_theme_mod('vome_breadcrumb_bg_color', '#222');
                    wp_enqueue_style('vome-breadcrumb-bg', VOME_THEME_CSS_DIR . 'color/default-color.css', array());
                    if ($color_code != '') {
                        $custom_css = '';
                        $custom_css .= ".breadcrumb-bg.gray-bg{ background: " . $color_code . "}";

                        wp_add_inline_style('vome-breadcrumb-bg', $custom_css);
                    }
                }
                add_action('wp_enqueue_scripts', 'vome_breadcrumb_bg_color');

                // breadcrumb-spacing top
                function vome_breadcrumb_spacing()
                {
                    $padding_px = get_theme_mod('vome_breadcrumb_spacing', '160px');
                    wp_enqueue_style('vome-breadcrumb-top-spacing', VOME_THEME_CSS_DIR . 'color/default-color.css', array());
                    if ($padding_px != '') {
                        $custom_css = '';
                        $custom_css .= ".breadcrumb-spacing{ padding-top: " . $padding_px . "}";

                        wp_add_inline_style('vome-breadcrumb-top-spacing', $custom_css);
                    }
                }
                add_action('wp_enqueue_scripts', 'vome_breadcrumb_spacing');

                // breadcrumb-spacing bottom
                function vome_breadcrumb_bottom_spacing()
                {
                    $padding_px = get_theme_mod('vome_breadcrumb_bottom_spacing', '160px');
                    wp_enqueue_style('vome-breadcrumb-bottom-spacing', VOME_THEME_CSS_DIR . 'color/default-color.css', array());
                    if ($padding_px != '') {
                        $custom_css = '';
                        $custom_css .= ".breadcrumb-spacing{ padding-bottom: " . $padding_px . "}";

                        wp_add_inline_style('vome-breadcrumb-bottom-spacing', $custom_css);
                    }
                }
                add_action('wp_enqueue_scripts', 'vome_breadcrumb_bottom_spacing');


                // scrollup
                function vome_scrollup_switch()
                {
                    $scrollup_switch = get_theme_mod('vome_scrollup_switch');
                    wp_enqueue_style('vome-scrollup-switch', VOME_THEME_CSS_DIR . 'color/default-color.css', array());
                    if ($scrollup_switch) {
                        $custom_css = '';
                        $custom_css .= "#scrollUp{ display: none !important;}";

                        wp_add_inline_style('vome-scrollup-switch', $custom_css);
                    }
                }
                add_action('wp_enqueue_scripts', 'vome_scrollup_switch');


                // theme color
                function vome_custom_color()
                {
                    $color_code = get_theme_mod('vome_color_option', '#FE6600');
                    wp_enqueue_style('vome-custom', VOME_THEME_CSS_DIR . 'color/default-color.css', array());
                    if ($color_code != '') {
                        $custom_css = '';
                        $custom_css .= ".btn,.header-search-user li:hover a,.s-video-btn:hover,.history-wrapper::before,#scrollUp,.play-btn a,.we-do-btn a::before,.portfolio-menu button.active,.portfolio-menu button:hover,.video-link a:hover,.bt-team .team-social a,.thumb-content a:hover,.footer-title::before,.b-btn,.hero-link .btn-border:hover,.b-btn:hover,.h2-section-title h2::before,.progress-bar,.cool-wroks-active .slick-arrow:hover i,.h2-section-title.contact-tittle h2::before,.contact-contents a:hover.contact-btn,.testmonial-item-active .slick-dots li.slick-active button,.testmonial-item2 i,.h4services-wrapper:hover .h4services-icon,.h4team--active .slick-dots li.slick-active button,.gallery__photo a:hover,.drama__rating--box,.h4-footer-social a:hover,.arrow-atyle .slick-arrow:hover,.single-about-team:hover .bottom-number span,.subscribe-03-area,.section-title.about-section-title span::before,.about-thumb a,.team-details-thumb ul,.widget .widget-title::before,.sidebar-tad li a:hover, .tagcloud a:hover,.basic-pagination-2 ul li span:hover, .basic-pagination ul li span.current,.basic-pagination-2 ul li a:hover, .basic-pagination-2 ul li.active a,.search-form button,.blog-post-tag a:hover,.c-bg-img::before,.mean-container a.meanmenu-reveal span,.h2-header-padding .mean-container a.meanmenu-reveal span,.preloader span{ background: " . $color_code . "}";

                        $custom_css .= ".main-menu nav ul li.active a,.main-menu nav ul li:hover > a,.s-video-btn,.history-icon i,.play-btn a:hover,.we-do-btn a,a:focus, a:hover, .portfolio-cat a:hover,a, button,.news-feed-content h3:hover a,.Industry ul li a,.footer-area-top ul.menu li a:hover, .footer-area-top ul li a:hover,.widget-posts-title a:hover,.main-menu.main-menu2 nav ul li:hover > a, .main-menu.main-menu2 nav ul li.active > a,.reward-tittle span,.progress-bar span,.cool-wroks-active .slick-next i,.test-author span,.h2-news-contnet span a,.h2-news-contnet h3 a:hover,.h2-news-contnet a.h2-news-btn,.about-left-conent span.a_sub_title,.desgnation-number h3,.desgnation-member span,.feeds-form-tittle span,.feeds-contents-top a,.h3-footer-tittle span a,.footer-social.footer-terms.f-right ul li:hover a,.trailer__features--icon i,.h4team__social--icons ul li a:hover,.h4team__social--icons ul li:hover a,.gallery__photo a,.movie__content--info > h4:hover a,.moview__content--ratings ul li i,.bs-content h3 a:hover, .bs-meta span a:hover,.bs-content h3 a:hover, .bs-meta span a:hover,.main-menu nav ul li .submenu li:hover > a,.about-bottom-icon h2,.section-title.about-section-title span,.arrow-atyle .slick-arrow,.about-team-content span,.about-me-top span,.about-me-bottom1 h2,.about-thumb a:hover,.biog-items i,.post-meta span i,.post-meta span a:hover,.blog-title a:hover,.widget .widget-posts-title a:hover,.widget li a:hover,.post-text blockquote footer,.bakix-navigation span,.bakix-navigation h4 a:hover,.section-title.section-title5 p.subscribe,.subscribe-form .input-box-area i,.mean-container a.meanmenu-reveal,.h2-header-padding .mean-container a.meanmenu-reveal,.h2-footer-contnet-right .footer-menu-widget ul li:hover a,#menu-full li a:hover { color: " . $color_code . "}";

                        $custom_css .= ".video-link a:hover,.reward-box-wrapper,.hero-link .btn-border:hover,.cool-wroks-active .slick-next i,.cool-wroks-active .slick-arrow:hover i,.arrow-atyle .slick-arrow,.basic-pagination-2 ul li span:hover, .basic-pagination ul li span.current,.basic-pagination-2 ul li a:hover, .basic-pagination-2 ul li.active a,.wp-block-quote, blockquote,.blog-post-tag a:hover,.comment-form textarea:focus,.comment-form input:focus,.mean-container a.meanmenu-reveal,.h2-header-padding .mean-container a.meanmenu-reveal{ border-color: " . $color_code . "}";
                        wp_add_inline_style('vome-custom', $custom_css);
                    }
                }
                add_action('wp_enqueue_scripts', 'vome_custom_color');
